0,1,32-fach IO
19,210,Rote Modul LED
16,17,Eingang 1
16,18,Eingang 2
16,19,Eingang 3
16,20,Eingang 4
16,21,Eingang 5
16,22,Eingang 6
16,23,Eingang 7
16,24,Eingang 8
16,33,Eingang 9
16,34,Eingang 10
16,35,Eingang 11
16,36,Eingang 12
16,37,Eingang 13
16,38,Eingang 14
16,39,Eingang 15
16,40,Eingang 16
19,49,Ausgang 1
19,50,Ausgang 2
19,51,Ausgang 3
19,52,Ausgang 4
19,53,Ausgang 5
19,54,Ausgang 6
19,55,Ausgang 7
19,56,Ausgang 8
19,97,Ausgang 9
19,98,Ausgang 10
19,99,Ausgang 11
19,100,Ausgang 12
19,101,Ausgang 13
19,102,Ausgang 14
19,103,Ausgang 15
19,104,Ausgang 16
32,1,Temperatursensor 1
32,2,Temperatursensor 2
32,3,Temperatursensor 3
32,4,Temperatursensor 4
32,5,Temperatursensor 5