0,1,Multitaster
20,1,Hintergrundbeleuchtung
21,50,Led 1
21,51,Led 2
21,49,Led 3
21,52,Led 4
21,54,Led 5
21,53,Led 6
16,33,Taster 1
16,34,Taster 2
16,24,Taster 3
16,35,Taster 4
16,23,Taster 5
16,36,Taster 6
16,33,Extern Taster 1
16,34,Extern Taster 2
16,35,Extern Taster 3
16,36,Extern Taster 4
16,55,Extern Taster 5
16,56,Extern Taster 6
21,65,Extern Led 1
21,66,Extern Led 2
21,67,Extern Led 3
21,68,Extern Led 4
21,69,Extern Led 5
21,70,Extern Led 6